# Rhasspy ASR DeepSpeech

Rhasspy ASR library that uses Mozilla's DeepSpeech 0.6.

## Requirements

* [Mozilla DeepSpeech 0.6.1](https://github.com/mozilla/DeepSpeech/releases/tag/v0.6.1)
* `generate_trie` in `$PATH` from [native client](https://github.com/mozilla/DeepSpeech/releases/download/v0.6.1/native_client.amd64.cpu.linux.tar.xz)
* `build_binary` in `$PATH` from [KenLM](https://github.com/kpu/kenlm)
    * [Pre-built binaries](https://github.com/synesthesiam/prebuilt-apps)
